clear
set more off

/**********************************************
Table 1:
Summary Statistics by Sample Store
**********************************************/
use 20150261_countsdata, clear
tabstat female white, by(storeid) stat(mean)

/**********************************************
Table 2:
Bag Use Before and After the Montgomery County Bag Tax
**********************************************/
use 20150261_countsdata, clear

gen state=1 if dc==1
replace state=2 if md==1
replace state=3 if va==1

egen statepost=group(state post)
tabstat usereuse useplastic nobags plastic_int reuse_int plastic reuse, stat(mean sd n) by(statepost)

/*************************************
Table 3: 
Effect of Tax Policy on Disposable Bag Use
****************************************/
set more off
use 20150261_countsdata, clear

reg useplastic postXmd post md dc, vce(cluster storeid)
estimates save "./estimates/useplastic1.ster", replace //no controls
reg useplastic postXmd post md dc black othrace female, vce(cluster storeid)
estimates save "./estimates/useplastic2.ster", replace //adds demographics
reg useplastic postXmd post md dc black othrace female aft night, vce(cluster storeid)
estimates save "./estimates/useplastic3.ster", replace //adds time of day
reg useplastic postXmd post black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/useplastic4.ster", replace //adds store FE


/*************************************
Table 4:
Effect of Tax Policy on Bag Use - Extensive and Intensive Margins
****************************************/
set more off
use 20150261_countsdata, clear

//extensive
reg usereuse postXmd post black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/usereuse.ster", replace
reg useplastic postXmd post black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/useplastic.ster", replace
reg nobags postXmd post black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/nobags.ster", replace

//intensive
reg plastic_int postXmd post black othrace female aft night S*, robust
estimates save "./estimates/plastic_int.ster", replace
reg reuse_int postXmd post black othrace female aft night S*, robust
estimates save "./estimates/reuse_int.ster", replace

/*************************************
Table 5: 
Effect of Tax Policy on Number of Disposable and Reusable Bags Used
****************************************/

/***********************
5a: linear demand
************************/
set more off
use 20150261_countsdata, clear

reg plastic postXmd post black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/plastic.ster", replace
reg reuse postXmd post black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/reuse.ster", replace

/***********************
5b: double-hurdle
************************/

* create stacked data set
local keepvar "postXmd post black othrace female aft night S* storeid"
* Step 1
use 20150261_countsdata, clear
keep reuse_int plastic_int `keepvar'
foreach var of varlist `keepvar' {
gen int`var'=`var'
gen ext`var'=0
}
gen y_reuse=reuse_int
gen y_plastic=plastic_int
gen inten=1
gen obs=_n
keep obs int* ext* y_reuse y_plastic storeid
save stacked.dta, replace
* Step 2
use 20150261_countsdata, clear
keep usereuse useplastic `keepvar'
foreach var of varlist `keepvar' {
gen int`var'=0
gen ext`var'=`var'
}
gen y_reuse=usereuse
gen y_plastic=useplastic
gen inten=0
gen obs=_n
keep obs int* ext* y_reuse y_plastic storeid
append using "./stacked.dta"
save "./stacked.dta", replace

* Regressions
clear
set more off

use 20150261_countsdata, clear
mean usereuse useplastic //0.308 and 0.635
mean plastic_int //2.15
mean reuse_int //1.65

use stacked.dta, clear
cd "./estimates"

local intcontrols "intpostXmd intpost intblack intothrace intfemale intaft intnight intS*"
local extcontrols "extpostXmd extpost extblack extothrace extfemale extaft extnight extS*"

//plastic
reg y_plastic `intcontrols' `extcontrols', vce(cluster storeid)
estimates save comb_plastic.ster, replace
estimates use comb_plastic
	foreach var in postXmd post black othrace female aft night {
	lincom ext`var'*2.15 + int`var'*.635
	}
estimates store "./estimates/comb_plastic"

//reuse
reg y_reuse `intcontrols' `extcontrols', vce(cluster storeid)
estimates save comb_reuse.ster, replace
estimates use comb_reuse
	foreach var in postXmd post black othrace female aft night {
	lincom ext`var'*1.65 + int`var'*.308
	}
estimates store "./estimates/comb_reuse"

/**********************************************
Table 6: 
Demographic Characteristics by Bonus Policy
**********************************************/
use 20150261_countsdata, clear
tabstat female white black, stat(mean sd) by(bonus)

/**********************************************
Table 7: 
Effect of Tax vs. Bonus Policy on Bag Use
**********************************************/
use 20150261_countsdata, clear

//disposable
reg useplastic tax bonus md dc if organic==0, vce(cluster storeid)
estimates save "./estimates/useplastic_bonus_nocov.ster", replace
reg useplastic tax bonus md dc black othrace female aft night if organic==0, vce(cluster storeid)
estimates save "./estimates/useplastic_bonus.ster", replace

//reusable
reg usereuse tax bonus md dc if organic==0, vce(cluster storeid)
estimates save "./estimates/usereuse_bonus_nocov.ster", replace
reg usereuse tax bonus md dc black othrace female aft night if organic==0, vce(cluster storeid)
estimates save "./estimates/usereuse_bonus.ster", replace

//for footnote regressions
reg useplastic tax bonus taxXbonus md dc black othrace female aft night if organic==0, vce(cluster storeid) 
estimates save "./estimates/useplastic_bonusDDD.ster", replace
reg usereuse tax bonus taxXbonus md dc black othrace female aft night if organic==0, vce(cluster storeid) 
estimates save "./estimates/usereuse_bonusDDD.ster", replace

/**********************************************
Table 8: 
Change in Social Norms after Implementation of Tax Policy
**********************************************/
use 20150261_surveydata, clear

reg guilt postXmd post md dc female white age age2 hs incomelt50 incomemiss, vce(cluster storeid)
estimates save "./estimates/guilt.ster", replace 
reg pressure postXmd post md dc female white age age2 hs incomelt50 incomemiss, vce(cluster storeid)
estimates save "./estimates/pressure.ster", replace 
reg upset postXmd post md dc female white age age2 hs incomelt50 incomemiss, vce(cluster storeid)
estimates save "./estimates/upset.ster", replace 
reg wasteful postXmd post md dc female white age age2 hs incomelt50 incomemiss, vce(cluster storeid)
estimates save "./estimates/wasteful.ster", replace 
reg support postXmd post md dc female white age age2 hs incomelt50 incomemiss, vce(cluster storeid)
estimates save "./estimates/support.ster", replace 

tabstat guilt pressure upset wasteful support if female~=. & white~=. & age~=. & hs~=., stat(mean n)

/**********************************************
Appendix Table 1: 
Demographic Characteristics Before and After the Montgomery County Bag Tax
**********************************************/
use 20150261_countsdata, clear
gen state=1 if dc==1
replace state=2 if md==1
replace state=3 if va==1
egen statepost=group(state post)
tabstat female white black, stat(mean sd) by(statepost)

/**********************************************
Appendix Table 2: 
Effect of Hypothetical Tax vs. Bonus Policy on Likelihood of Using Reusable Bags

note: coefficient on postXmdXbonus even smaller if exclude organic stores
**********************************************/
use 20150261_countsdata, clear

gen postXmdXbonus=postXmd*bonus
gen postXbonus=post*bonus

reg useplastic postXmd postXmdXbonus post postXbonus black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/app2_extdisp.ster", replace
reg usereuse postXmd postXmdXbonus post postXbonus black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/app2_extreuse.ster", replace
reg nobags postXmd postXmdXbonus post postXbonus black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/app2_extnobag.ster", replace
reg plastic_int postXmd postXmdXbonus post postXbonus black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/app2_intdisp.ster", replace
reg reuse_int postXmd postXmdXbonus post postXbonus black othrace female aft night S*, vce(cluster storeid)
estimates save "./estimates/app2_intreuse.ster", replace

/**********************************************
Appendix Table 4: 
Effect of Hypothetical Tax vs. Bonus Policy on Likelihood of Using Reusable Bags
**********************************************/
use 20150261_surveydata, clear

mean hyp_def if hyp_taxpolicy==0
reg hyp_def hyp_taxpolicy female white age age2 hs incomelt50 incomemiss, robust
estimates save "./estimates/survey_hypdef.ster", replace 

/**********************************************
Appendix Table 5: 
Effect of Hypothetical Tax vs. Fee on Likelihood of Using Reusable Bags
**********************************************/
use 20150261_mturkdata, clear
*note: response to hypothetical policy not answered if already bring reusable bags 

reg hyp_def tax female white hs incomelt50 age age2, robust
estimates save "./estimates/mturktax_hyp5.ster", replace 

tabstat hyp_def if female~=. & white~=. & hs~=. & incomelt50~=. & age~=., stat(mean n)


/********************************************************************************
Figure 3: Extensive Margin Bag Use by Location, Time Period, and Bag Type
*********************************************************************************/
use 20150261_countsdata, clear

foreach var in useplastic usereuse {
mean `var' if va==1 & post==0
mean `var' if va==1 & post==1
mean `var' if md==1 & post==0
mean `var' if md==1 & post==1
mean `var' if dc==1 & post==0
mean `var' if dc==1 & post==1
}

/********************************************************************************
Figure 4: Extensive Margin Bag Use by Store Policy and Bag Type
*********************************************************************************/
use 20150261_countsdata, clear
drop if organic==1

foreach var in useplastic usereuse {
//no incentive
mean `var' if va==1 & post==0 & bonus==0
mean `var' if va==1 & post==1 & bonus==0
mean `var' if md==1 & post==0 & bonus==0
//bonus only
mean `var' if va==1 & post==0 & bonus==1
mean `var' if va==1 & post==1 & bonus==1
mean `var' if md==1 & post==0 & bonus==1
//tax only
mean `var' if md==1 & post==1 & bonus==0
mean `var' if dc==1 & post==0 & bonus==0
mean `var' if dc==1 & post==1 & bonus==0
//tax and bonus
mean `var' if md==1 & post==1 & bonus==1
mean `var' if dc==1 & post==0 & bonus==1
mean `var' if dc==1 & post==1 & bonus==1
}

/*************************************************
Additional Analysis: Coefficient of Loss Aversion

1) Calculate alpha assuming normal dist with awareness adjustment
2) Bootstrap alpha (w/ replacement) to get many values of alpha
3) Calculate CI with bootstrapped std errors
*************************************************/

//bonus awareness
use 20150261_surveydata, clear
tab awarebonus //52% aware of bonus policy at bonus stores

*program to calculate coefficient of loss aversion
program drop alpha
program alpha, rclass
version 13
args y
tempname mean1 
tempname mean2 
tempname mean3 
summarize `y' if poltype==1, meanonly
scalar `mean1' = r(mean)
summarize `y' if poltype==2, meanonly
scalar `mean2' = r(mean)
summarize `y' if poltype==3, meanonly
scalar `mean3' = r(mean)

return scalar mean1=`mean1'
return scalar mean2=`mean2'
return scalar mean3=`mean3'
return scalar alpha = [invnorm(`mean3')-invnorm(`mean1')]/[invnorm(`mean1'+(`mean2'-`mean1')/.52)-invnorm(`mean1')]
end

* run program
use 20150261_countsdata, clear
drop if organic==1
gen incentive=0 if tax==0 & bonus==0
replace incentive=5 if tax==1 | bonus==1
replace incentive=10 if tax==1 & bonus==1
egen poltype=group(incentive tax)
bootstrap alpha=r(alpha) mean1=r(mean1) mean2=r(mean2) mean3=r(mean3), reps(999) seed(1) saving(alphas, replace): alpha usereuse

* 95% CI on alpha
use alphas, clear
sum alpha, d //95% CI is 5-95 percentile: [3.3, 14.8]
